@@ -24,6 +24,14 @@ PrimitiveTypes = Union[
     Type[bool],
     Type[None],
 ]
+PrimitiveTypesList = (
+    str,
+    int,
+    float,
+    Decimal,
+    bool,
+    type(None),
+)
 PrimitiveTVar = TypeVar(
     "PrimitiveTVar", str, int, float, Decimal, bool, Type[None]
 )
@@ -31,7 +39,6 @@ NotNonePrimTvar = TypeVar("NotNonePrimTvar", str, int, float, Decimal, bool)
 
 
 def is_primitive(raw: _T) -> TypeGuard[Primitive]:
-    primitives = (str, int, float, bool, Decimal, type(None))
-    if isinstance(raw, primitives):
+    if raw is None or isinstance(raw, PrimitiveTypesList):
         return True
     return False
